
high level API reference
========================

- :class:`deltachat.account.Account` (your main entry point, creates the
  other classes)
- :class:`deltachat.contact.Contact`
- :class:`deltachat.chat.Chat`
- :class:`deltachat.message.Message`

Account
-------

.. autoclass:: deltachat.account.Account
    :members:


Contact
-------

.. autoclass:: deltachat.contact.Contact
    :members:

Chat
----

.. autoclass:: deltachat.chat.Chat
    :members:

Message
-------

.. autoclass:: deltachat.message.Message
    :members:

